import 'package:flutter/material.dart';
import 'package:shared_preferences/shared_preferences.dart';

import '../../dialogs/settings_dialog.dart';
import 'create_room_page.dart';

// 새로 추가할 페이지들
import 'room_search_home_page.dart';

class MainPage extends StatefulWidget {
  const MainPage({Key? key}) : super(key: key);

  @override
  _MainPageState createState() => _MainPageState();
}

class _MainPageState extends State<MainPage> {
  bool _isBackButtonVisible = false; // 뒤로가기 버튼 상태

  @override
  void initState() {
    super.initState();
    _isBackButtonVisible = false;
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      // (A) 전체 배경 흰색 → 텍스트/버튼은 블랙 위주
      backgroundColor: Colors.white,

      // (B) 상단 AppBar: 블랙 배경, 흰색 아이콘
      appBar: AppBar(
        backgroundColor: Colors.black,
        elevation: 0,
        automaticallyImplyLeading: false, // 뒤로가기 버튼 자동생성 비활성
        title: const Text(
          'ALLSCORE',
          style: TextStyle(color: Colors.white),
        ),
        actions: [
          IconButton(
            icon: const Icon(Icons.settings, color: Colors.white),
            onPressed: () {
              showSettingsDialog(context); // 설정 모달 호출
            },
          ),
        ],
      ),

      // (C) 본문: 위아래 공간 분배
      body: Column(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          // 중간 영역(“방 만들기” / “참여하기”)
          Expanded(
            child: Padding(
              padding: const EdgeInsets.all(16.0),
              child: Center(
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: [
                    // (C1) 방 만들기 버튼
                    _buildBlackWhiteButton(
                      label: '방만들기',
                      onTap: () {
                        Navigator.push(
                          context,
                          MaterialPageRoute(builder: (_) => const CreateRoomPage()),
                        );
                      },
                    ),
                    const SizedBox(width: 16),
                    // (C2) 참여하기 버튼 => RoomSearchHomePage로 이동
                    _buildBlackWhiteButton(
                      label: '참여하기',
                      onTap: () async {
                        Navigator.push(
                          context,
                          MaterialPageRoute(builder: (_) => const RoomSearchHomePage()),
                        );
                      },
                    ),
                  ],
                ),
              ),
            ),
          ),

          // (D) 광고 영역
          Container(
            color: Colors.white,
            padding: const EdgeInsets.only(bottom: 24),
            child: Column(
              mainAxisSize: MainAxisSize.min,
              children: [
                Container(
                  height: 50,
                  width: 300,
                  color: Colors.grey.shade400,
                  child: const Center(
                    child: Text(
                      '구글 광고',
                      style: TextStyle(color: Colors.black),
                    ),
                  ),
                ),
              ],
            ),
          ),

          // (E) 임시 버튼: 방 생성 완료 이동
          Center(
            child: OutlinedButton(
              onPressed: () {
                // 예시로 팀전 대기방(15번 방) 이동
                // 실무에서는 제외하거나 debugging용
                // (아직 남겨두고 싶다면 유지)
              },
              style: OutlinedButton.styleFrom(
                backgroundColor: Colors.white,
                side: const BorderSide(color: Colors.black54, width: 1),
                shape: RoundedRectangleBorder(
                  borderRadius: BorderRadius.circular(40),
                ),
                padding: const EdgeInsets.symmetric(vertical: 12, horizontal: 60),
              ),
              child: const Text(
                '방 생성 완료 이동(임시)',
                style: TextStyle(color: Colors.black, fontSize: 16),
              ),
            ),
          ),
          const SizedBox(height: 16),
        ],
      ),
    );
  }

  /// 블랙 라인 + 흰 배경 스타일의 버튼
  Widget _buildBlackWhiteButton({
    required String label,
    required VoidCallback onTap,
  }) {
    return ElevatedButton(
      onPressed: onTap,
      style: ElevatedButton.styleFrom(
        backgroundColor: Colors.white,
        foregroundColor: Colors.black,
        side: const BorderSide(color: Colors.black, width: 1),
        padding: const EdgeInsets.symmetric(vertical: 36, horizontal: 32),
        shape: RoundedRectangleBorder(
          borderRadius: BorderRadius.circular(20),
        ),
      ),
      child: Text(label, style: const TextStyle(color: Colors.black)),
    );
  }
}
