import 'package:flutter/material.dart';
import 'room_search_list_page.dart';

/// 방 검색 홈 화면
/// - "대기중/진행중/종료" 버튼 3개로 구분
/// - 버튼 누르면 RoomSearchListPage로 이동 + 상태값 전달
class RoomSearchHomePage extends StatelessWidget {
  const RoomSearchHomePage({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,

      appBar: AppBar(
        backgroundColor: Colors.black,
        elevation: 0,
        title: const Text('방 검색', style: TextStyle(color: Colors.white)),
        leading: IconButton(
          icon: const Icon(Icons.arrow_back_ios, color: Colors.white),
          onPressed: () => Navigator.pop(context),
        ),
      ),

      // 화면 하단 광고 영역
      bottomNavigationBar: Container(
        height: 50,
        color: Colors.grey.shade400,
        child: const Center(
          child: Text('구글 광고', style: TextStyle(color: Colors.black)),
        ),
      ),

      // 본문: 중앙에 3개 버튼 (대기중 / 진행중 / 종료)
      body: Center(
        child: Row(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            _buildSearchStatusButton(context, label: '대기중', status: 'WAIT'),
            const SizedBox(width: 16),
            _buildSearchStatusButton(context, label: '진행중', status: 'RUNNING'),
            const SizedBox(width: 16),
            _buildSearchStatusButton(context, label: '종료', status: 'FINISH'),
          ],
        ),
      ),
    );
  }

  /// 동일한 크기로 버튼
  Widget _buildSearchStatusButton(
    BuildContext context, {
    required String label,
    required String status,
  }) {
    return SizedBox(
      width: 100,
      height: 100,
      child: ElevatedButton(
        onPressed: () {
          // RoomSearchListPage로 이동하며, roomStatus 전달
          Navigator.push(
            context,
            MaterialPageRoute(
              builder: (_) => RoomSearchListPage(roomStatus: status),
            ),
          );
        },
        style: ElevatedButton.styleFrom(
          backgroundColor: Colors.white,
          foregroundColor: Colors.black,
          side: const BorderSide(color: Colors.black, width: 1),
          shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(12)),
          padding: EdgeInsets.zero,
        ),
        child: Text(label, style: const TextStyle(color: Colors.black)),
      ),
    );
  }
}
