import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:shared_preferences/shared_preferences.dart';
import 'dart:convert';
import '../../dialogs/response_dialog.dart';
import 'package:crypto/crypto.dart';
import '../../plugins/api.dart';
import '../../plugins/utils.dart';
import 'withdrawal_page.dart';
import 'package:image_picker/image_picker.dart';
import 'dart:io';
// import 'package:path/path.dart';

class MyPage extends StatefulWidget {
  const MyPage({Key? key}) : super(key: key);

  @override
  _MyPageState createState() => _MyPageState();
}

class _MyPageState extends State<MyPage> {
  String user_nickname = '';
  String user_pw = '';
  String new_user_pw = '**********';
  String user_email = '';
  String user_department = '';
  String user_introduce_myself = '';
  String user_profile_image = '';
  bool isEditingNickname = false;
  bool isEditingPassword = false;
  bool isConfirmingPassword = false;
  String confirmPassword = '';
  final TextEditingController _nicknameController = TextEditingController();
  final TextEditingController _passwordController = TextEditingController();
  final TextEditingController _confirmPasswordController = TextEditingController();
  final FocusNode _nicknameFocusNode = FocusNode();
  final FocusNode _passwordFocusNode = FocusNode();
  final FocusNode _confirmPasswordFocusNode = FocusNode();
  String? _passwordError;
  String? _emailError;
  final TextEditingController _emailController = TextEditingController();
  final FocusNode _emailFocusNode = FocusNode();
  bool isEditingEmail = false;
  final TextEditingController _departmentController = TextEditingController();
  final FocusNode _departmentFocusNode = FocusNode();
  bool isEditingDepartment = false;
  final TextEditingController _introduceController = TextEditingController();
  String? _nicknameError;
  XFile? _image; // 선택된 이미지 파일

  @override
  void initState() {
    super.initState();
    _fetchUserInfo();
  }

  @override
  void dispose() {
    _nicknameController.dispose();
    _passwordController.dispose();
    _confirmPasswordController.dispose();
    _nicknameFocusNode.dispose();
    _passwordFocusNode.dispose();
    _confirmPasswordFocusNode.dispose();
    _emailController.dispose();
    _emailFocusNode.dispose();
    _departmentController.dispose();
    _departmentFocusNode.dispose();
    _introduceController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () {
        if (isEditingNickname) {
          setState(() {
            user_nickname = _nicknameController.text;
            isEditingNickname = false;
            _nicknameFocusNode.unfocus();
          });
        }
        if (isEditingPassword) {
          setState(() {
            new_user_pw = _passwordController.text;
            isEditingPassword = false;
            _passwordFocusNode.unfocus();
          });
        }
        if (isConfirmingPassword) {
          setState(() {
            isConfirmingPassword = false;
            _confirmPasswordFocusNode.unfocus();
          });
        }
        if (isEditingEmail) {
          setState(() {
            user_email = _emailController.text;
            isEditingEmail = false;
            _emailFocusNode.unfocus();
          });
        }
        if (isEditingDepartment) {
          setState(() {
            user_department = _departmentController.text;
            isEditingDepartment = false;
            _departmentFocusNode.unfocus();
          });
        }
      },
      child: Scaffold(
        backgroundColor: Colors.white,
        appBar: AppBar(
          title: const Text('MY PAGE', style: TextStyle(color: Colors.black)),
          backgroundColor: Colors.transparent,
          leading: IconButton(
            icon: const Icon(Icons.arrow_back_ios, color: Colors.black),
            onPressed: () {
              Navigator.pop(context);
              Navigator.pop(context);
            },
          ),
        ),
        body: SingleChildScrollView(
          child: Padding(
            padding: const EdgeInsets.all(16.0),
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Card(
                  elevation: 4,
                  color: Colors.white,
                  shape: RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(10),
                  ),
                  child: Padding(
                    padding: const EdgeInsets.all(16.0),
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: [
                        const Text(
                          '닉네임:',
                          style: TextStyle(fontSize: 18, fontWeight: FontWeight.bold),
                        ),
                        Expanded(
                          child: GestureDetector(
                            onTap: () {
                              setState(() {
                                isEditingNickname = true;
                                _nicknameController.text = user_nickname;
                                _nicknameFocusNode.requestFocus();
                              });
                            },
                            child: isEditingNickname
                                ? TextField(
                                    controller: _nicknameController,
                                    focusNode: _nicknameFocusNode,
                                    onChanged: (newNickname) {
                                      setState(() {
                                        user_nickname = newNickname;
                                        // 닉네임 패턴 검증
                                        if (!_isNicknameValidPattern(user_nickname)) {
                                          // 패턴이 일치하지 않을 경우 안내 문구 표시
                                          _nicknameError = '닉네임은 2~20자 영문, 한글, 숫자만 사용할 수 있습니다.';
                                        } else {
                                          _nicknameError = null; // 패턴이 일치하면 오류 메시지 초기화
                                        }
                                      });
                                    },
                                    onSubmitted: (newNickname) {
                                      setState(() {
                                        user_nickname = newNickname;
                                        isEditingNickname = false;
                                        _nicknameFocusNode.unfocus();
                                      });
                                    },
                                    decoration: InputDecoration(
                                      hintText: '닉네임을 입력하세요',
                                      border: InputBorder.none,
                                      contentPadding: const EdgeInsets.symmetric(vertical: 10.0, horizontal: 8.0),
                                    ),
                                  )
                                : Container(
                                    padding: const EdgeInsets.symmetric(horizontal: 8.0),
                                    child: Text(
                                      user_nickname,
                                      style: const TextStyle(fontSize: 18, color: Colors.black54),
                                    ),
                                  ),
                          ),
                        ),
                      ],
                    ),
                  ),
                ),
                // 닉네임 오류 메시지 추가
                if (_nicknameError != null) 
                  Padding(
                    padding: const EdgeInsets.only(top: 8.0),
                    child: Text(
                      _nicknameError!,
                      style: const TextStyle(color: Colors.red, fontSize: 12),
                    ),
                  ),
                const SizedBox(height: 16),
                Card(
                  elevation: 4,
                  color: Colors.white,
                  shape: RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(10),
                  ),
                  child: Padding(
                    padding: const EdgeInsets.all(16.0),
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: [
                        const Text(
                          '비밀번호:',
                          style: TextStyle(fontSize: 18, fontWeight: FontWeight.bold),
                        ),
                        Expanded(
                          child: GestureDetector(
                            onTap: () {
                              setState(() {
                                isEditingPassword = true;
                                _passwordController.text = new_user_pw.replaceAll(RegExp(r'.'), '*');
                                _passwordFocusNode.requestFocus();
                              });
                            },
                            child: isEditingPassword
                                ? TextField(
                                    controller: _passwordController,
                                    focusNode: _passwordFocusNode,
                                    obscureText: true,
                                    onChanged: (newPassword) {
                                      setState(() {
                                        new_user_pw = newPassword;
                                        _passwordError = _isPasswordValidPattern(new_user_pw) ? null : '비밀번호는 8~20자 영문과 숫자가 반드시 포함되어야 합니다.';
                                      });
                                    },
                                    onSubmitted: (newPassword) {
                                      setState(() {
                                        isEditingPassword = false;
                                        _passwordFocusNode.unfocus();
                                      });
                                    },
                                    decoration: InputDecoration(
                                      hintText: '비밀번호를 입력하세요',
                                      border: InputBorder.none,
                                      contentPadding: const EdgeInsets.symmetric(vertical: 10.0, horizontal: 8.0),
                                    ),
                                  )
                                : Container(
                                    padding: const EdgeInsets.symmetric(horizontal: 8.0),
                                    child: Text(
                                      '**********',
                                      style: const TextStyle(fontSize: 18, color: Colors.black54),
                                    ),
                                  ),
                          ),
                        ),
                      ],
                    ),
                  ),
                ),
                // 비밀번호 오류 메시지 추가
                if (_passwordError != null) 
                  Padding(
                    padding: const EdgeInsets.only(top: 8.0),
                    child: Text(
                      _passwordError!,
                      style: const TextStyle(color: Colors.red, fontSize: 12),
                    ),
                  ),
                const SizedBox(height: 16),
                Card(
                  elevation: 4,
                  color: Colors.white,
                  shape: RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(10),
                  ),
                  child: Padding(
                    padding: const EdgeInsets.all(16.0),
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: [
                        const Text(
                          '비밀번호 확인:',
                          style: TextStyle(fontSize: 18, fontWeight: FontWeight.bold),
                        ),
                        Expanded(
                          child: GestureDetector(
                            onTap: () {
                              setState(() {
                                isConfirmingPassword = true;
                                _confirmPasswordController.text = '';
                                _confirmPasswordFocusNode.requestFocus();
                              });
                            },
                            child: isConfirmingPassword
                                ? TextField(
                                    controller: _confirmPasswordController,
                                    focusNode: _confirmPasswordFocusNode,
                                    obscureText: true,
                                    onChanged: (value) {
                                      setState(() {
                                        confirmPassword = value;
                                      });
                                    },
                                    onSubmitted: (newPassword) {
                                      setState(() {
                                        isConfirmingPassword = false;
                                        _confirmPasswordFocusNode.unfocus();
                                      });
                                    },
                                    decoration: InputDecoration(
                                      hintText: '비밀번호를 다시 입력해주세요',
                                      border: InputBorder.none,
                                      contentPadding: const EdgeInsets.symmetric(vertical: 10.0, horizontal: 8.0),
                                    ),
                                  )
                                : Container(
                                    padding: const EdgeInsets.symmetric(horizontal: 8.0),
                                    child: Text(
                                      '*' * confirmPassword.length,
                                      style: const TextStyle(fontSize: 18, color: Colors.black54),
                                    ),
                                  ),
                          ),
                        ),
                      ],
                    ),
                  ),
                ),
                // 비밀번호 일치 여부 안내 텍스트 추가
                const SizedBox(height: 8),
                Text(
                  (new_user_pw == confirmPassword) 
                      ? '비밀번호가 일치합니다.' 
                      : (confirmPassword.isNotEmpty ? '비밀번호가 일치하지 않습니다.' : ''),
                  style: TextStyle(
                    fontSize: 16,
                    color: (new_user_pw == confirmPassword) ? Colors.green : Colors.red,
                  ),
                ),
                Card(
                  elevation: 4,
                  color: Colors.white,
                  shape: RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(10),
                  ),
                  child: Padding(
                    padding: const EdgeInsets.all(16.0),
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: [
                        const Text(
                          '이메일:',
                          style: TextStyle(fontSize: 18, fontWeight: FontWeight.bold),
                        ),
                        Expanded(
                          child: GestureDetector(
                            onTap: () {
                              setState(() {
                                isEditingEmail = true;
                                _emailController.text = user_email;
                                _emailFocusNode.requestFocus();
                              });
                            },
                            child: isEditingEmail
                                ? TextField(
                                    controller: _emailController,
                                    focusNode: _emailFocusNode,
                                    onChanged: (value) {
                                      setState(() {
                                        user_email = value;
                                        _emailError = _isEmailValid(user_email) ? null : '올바른 이메일 형식을 입력해주세요.';
                                      });
                                    },
                                    onSubmitted: (newEmail) {
                                      setState(() {
                                        user_email = newEmail;
                                        isEditingEmail = false;
                                        _emailFocusNode.unfocus();
                                      });
                                    },
                                    decoration: InputDecoration(
                                      hintText: '이메일을 입력하세요',
                                      border: InputBorder.none,
                                      contentPadding: const EdgeInsets.symmetric(vertical: 10.0, horizontal: 8.0),
                                    ),
                                  )
                                : Container(
                                    padding: const EdgeInsets.symmetric(horizontal: 8.0),
                                    child: Text(
                                      user_email,
                                      style: const TextStyle(fontSize: 18, color: Colors.black54),
                                    ),
                                  ),
                          ),
                        ),
                      ],
                    ),
                  ),
                ),
                // 이메일 오류 메시지 추가
                if (_emailError != null) 
                  Padding(
                    padding: const EdgeInsets.only(top: 8.0),
                    child: Text(
                      _emailError!,
                      style: const TextStyle(color: Colors.red, fontSize: 12),
                    ),
                  ),
                const SizedBox(height: 8),
                Card(
                  elevation: 4,
                  color: Colors.white,
                  shape: RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(10),
                  ),
                  child: Padding(
                    padding: const EdgeInsets.all(16.0),
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: [
                        const Text(
                          '소속:',
                          style: TextStyle(fontSize: 18, fontWeight: FontWeight.bold),
                        ),
                        Expanded(
                          child: GestureDetector(
                            onTap: () {
                              setState(() {
                                isEditingDepartment = true;
                                _departmentController.text = user_department;
                                _departmentFocusNode.requestFocus();
                              });
                            },
                            child: isEditingDepartment
                                ? TextField(
                                    controller: _departmentController,
                                    focusNode: _departmentFocusNode,
                                    onChanged: (value) {
                                      setState(() {
                                        user_department = value;
                                      });
                                    },
                                    onSubmitted: (newDepartment) {
                                      setState(() {
                                        user_department = newDepartment;
                                        isEditingDepartment = false;
                                        _departmentFocusNode.unfocus();
                                      });
                                    },
                                    decoration: InputDecoration(
                                      hintText: '소속을 입력하세요',
                                      border: InputBorder.none,
                                      contentPadding: const EdgeInsets.symmetric(vertical: 10.0, horizontal: 8.0),
                                    ),
                                  )
                                : Container(
                                    padding: const EdgeInsets.symmetric(horizontal: 8.0),
                                    child: Text(
                                      user_department,
                                      style: const TextStyle(fontSize: 18, color: Colors.black54),
                                    ),
                                  ),
                          ),
                        ),
                      ],
                    ),
                  ),
                ),
                const SizedBox(height: 8),
                // 소속 박스 아래에 텍스트 추가
                const SizedBox(height: 8),
                const Text(
                  '프로필 이미지를 설정해주세요.',
                  style: TextStyle(fontSize: 16, color: Colors.black),
                ),
                const SizedBox(height: 16), // 여백 추가
                Center(
                  child: Column(
                    mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                    children: [
                      GestureDetector(
                        onTap: () {
                          _selectImage();
                        },
                        child: Container(
                          width: 100, // 정사각형 가로 길이
                          height: 100, // 정사각형 세로 길이
                          decoration: BoxDecoration(
                            color: Colors.white, // 내부 색상
                            border: Border.all(color: Colors.black), // 테두리 색상
                            borderRadius: BorderRadius.circular(20), // 모서리 둥글게
                          ),
                          child: ClipRRect(
                            borderRadius: BorderRadius.circular(20), // 모서리 둥글게
                            child: Image.network(
                              'https://eldsoft.com:8097/images${user_profile_image}', // 프로필 이미지 URL
                              fit: BoxFit.cover, // 이미지 크기 조정
                              errorBuilder: (context, error, stackTrace) {
                                return const Center(child: Text('이미지를 불러올 수 없습니다.')); // 오류 처리
                              },
                            ),
                          ),
                        ),
                      ),
                      const SizedBox(height: 8),
                      const Text(
                        '이미지를 클릭하시면 새로 등록할 수 있습니다.',
                        textAlign: TextAlign.center, // 가운데 정렬
                        style: TextStyle(fontSize: 12, color: Colors.blueGrey), // 색상 변경
                      ),
                    ],
                  ),
                ),
                const SizedBox(height: 8),
                const Text(
                  '다른 유저에게 자신을 소개해주세요.',
                  style: TextStyle(fontSize: 16, color: Colors.black),
                ),
                const SizedBox(height: 8), // 여백 추가
                TextField(
                  controller: _introduceController..text = user_introduce_myself, // 기본값 설정
                  maxLines: 5, // 여러 줄 입력 가능
                  decoration: InputDecoration(
                    hintText: '자신을 소개하는 내용을 입력하세요...',
                    border: OutlineInputBorder(
                      borderRadius: BorderRadius.circular(10), // 모서리 둥글게
                      borderSide: const BorderSide(color: Colors.black), // 테두리 색상
                    ),
                    contentPadding: const EdgeInsets.all(10), // 패딩 추가
                  ),
                  onChanged: (value) {
                    setState(() {
                      user_introduce_myself = value; // 자기소개 내용 업데이트
                    });
                  },
                ),
                const SizedBox(height: 30), // 여백 추가
                Center(
                  child: OutlinedButton(
                    onPressed: () {
                      // 수정하기 버튼 클릭 시 모달창 열기
                      _showEditDialog(); // 모달창을 여는 메서드 호출
                    },
                    style: OutlinedButton.styleFrom(
                      backgroundColor: Colors.white, // 버튼 배경색
                      side: const BorderSide(color: Colors.black54, width: 1), // 테두리 색상 및 두께
                      shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(40), // 모서리 둥글게 조정
                      ),
                      padding: const EdgeInsets.symmetric(vertical: 12, horizontal: 60), // 버튼 패딩
                    ),
                    child: const Text(
                      '수정하기',
                      style: TextStyle(color: Colors.black, fontSize: 16), // 텍스트 색상 및 크기
                    ),
                  ),
                ),
                const SizedBox(height: 10), // 여백 추가
                Center(
                  child: OutlinedButton(
                    onPressed: () {
                      // 회원탈퇴 버튼 클릭 시 WithdrawalPage로 이동
                      Navigator.push(
                        context,
                        MaterialPageRoute(builder: (context) => const WithdrawalPage()),
                      );
                    },
                    style: OutlinedButton.styleFrom(
                      backgroundColor: Colors.white, // 버튼 배경색
                      side: const BorderSide(color: Colors.black54, width: 1), // 테두리 색상 및 두께
                      shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(40), // 모서리 둥글게 조정
                      ),
                      padding: const EdgeInsets.symmetric(vertical: 12, horizontal: 60), // 버튼 패딩
                    ),
                    child: const Text(
                      '회원탈퇴',
                      style: TextStyle(color: Colors.black, fontSize: 16), // 텍스트 색상 및 크기
                    ),
                  ),
                ),
                const SizedBox(height: 30), // 여백 추가
              ],
            ),
          ),
        ),
      ),
    );
  }

  Future<void> _fetchUserInfo() async {
    SharedPreferences prefs = await SharedPreferences.getInstance();
    String? authToken = prefs.getString('auth_token');

    final response = await Api.serverRequest(
      uri: '/user/myinfo',
      body: {},
    );

    if (response['result'] == 'OK') {
      final jsonResponse = response['response'];
      print('응답: $jsonResponse');
      if (jsonResponse['result'] == 'OK') {
        SharedPreferences prefs = await SharedPreferences.getInstance();
        await prefs.setString('auth_token', jsonResponse['auth']['token']);

        setState(() {
          user_nickname = jsonResponse['data']['nickname'];
          user_email = jsonResponse['data']['user_email'];
          user_department = jsonResponse['data']['department'];
          user_introduce_myself = jsonResponse['data']['introduce_myself'];
          user_profile_image = jsonResponse['data']['profile_img'];
        });
      } else {
        showResponseDialog(context, '${jsonResponse['response_info']['msg_title']}', '${jsonResponse['response_info']['msg_content']}');
      }
    } else {
      showResponseDialog(context, '요청 실패', '서버에 문제가 있습니다. 관리자에게 문의해주세요.');
    }
  }

  bool _isPasswordValidPattern(String password) {
    // 비밀번호는 최소 8자 이상, 최대 20자 이하의 영문과 숫자가 반드시 포함되어야 하며, 다른 문자도 허용
    return password.length >= 8 && password.length <= 20 && 
    RegExp(r'^(?=.*[A-Za-z])(?=.*\d)[A-Za-z\d\S]{8,20}$').hasMatch(password);
  }

  bool _isEmailValid(String email) {
    return RegExp(r'^[\w-\.]+@([\w-]+\.)+[\w-]{2,4}$').hasMatch(email); // 이메일 패턴 검증
  }

  Future<void> _selectImage() async {
    // 이미지 선택 다이얼로그를 표시하는 로직을 추가합니다.
    showDialog(
      context: context,
      builder: (BuildContext context) {
        return Dialog(
          backgroundColor: Colors.transparent, // 배경을 투명하게 설정
          child: Container(
            decoration: BoxDecoration(
              color: Colors.white, // 배경색을 흰색으로 설정
              borderRadius: BorderRadius.circular(16), // 모서리 둥글게 조정
            ),
            padding: const EdgeInsets.all(16),
            child: Column(
              mainAxisSize: MainAxisSize.min,
              children: [
                const Text(
                  '프로필 이미지 선택',
                  style: TextStyle(fontSize: 20, fontWeight: FontWeight.bold),
                ),
                const SizedBox(height: 16),
                Row(
                  mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                  children: [
                    Expanded(
                      child: ElevatedButton(
                        onPressed: () {
                          Navigator.of(context).pop(); // 다이얼로그 닫기
                          _pickImage(); // 갤러리에서 이미지 선택
                        },
                        style: ElevatedButton.styleFrom(
                          backgroundColor: Colors.white, // 버튼 배경색
                          side: const BorderSide(color: Colors.black), // 테두리 색상
                          shape: RoundedRectangleBorder(
                            borderRadius: BorderRadius.circular(10), // 모서리 둥글게
                          ),
                        ),
                        child: const Text(
                          '갤러리',
                          style: TextStyle(color: Colors.black), // 텍스트 색상
                        ),
                      ),
                    ),
                    const SizedBox(width: 8), // 버튼 간격
                    Expanded(
                      child: ElevatedButton(
                        onPressed: () {
                          Navigator.of(context).pop(); // 취소
                        },
                        style: ElevatedButton.styleFrom(
                          backgroundColor: Colors.white, // 버튼 배경색
                          side: const BorderSide(color: Colors.black), // 테두리 색상
                          shape: RoundedRectangleBorder(
                            borderRadius: BorderRadius.circular(10), // 모서리 둥글게
                          ),
                        ),
                        child: const Text(
                          '취소',
                          style: TextStyle(color: Colors.black), // 텍스트 색상
                        ),
                      ),
                    ),
                  ],
                ),
              ],
            ),
          ),
        );
      },
    ).then((pickedFile) {
      if (pickedFile != null) {
        // 선택된 이미지에 따라 처리하는 로직을 추가합니다.
        if (pickedFile == 'gallery') {
          _pickImage(); // 갤러리에서 이미지 선택
        }
      }
    });
  }

  // 모달창을 여는 메서드 추가
  void _showEditDialog() {
    // 현재 비밀번호와 confirmPassword 비교
    if (new_user_pw != '**********') {
      if (!_isPasswordValidPattern(new_user_pw)) {
        showResponseDialog(context, '수정하기 실패', '비밀번호 패턴을 확인해주세요.');
        return;
      }
      if (new_user_pw != confirmPassword) {
        showResponseDialog(context, '수정하기 실패', '비밀번호가 일치하지 않습니다.');
        return; // 비밀번호가 일치하지 않으면 모달창을 열지 않음
      }
    }
    if (!_isEmailValid(user_email)) {
      showResponseDialog(context, '수정하기 실패', '이메일 형식을 확인해주세요.');
      return;
    }
    if (!_isNicknameValidPattern(user_nickname)) {
      showResponseDialog(context, '수정하기 실패', '닉네임 패턴을 확인해주세요.');
      return;
    }

    showDialog(
      context: context,
      builder: (BuildContext context) {
        return AlertDialog(
          backgroundColor: Colors.white, // 모달창 배경색을 흰색으로 설정
          title: const Center( // 제목을 가운데 정렬
            child: Text(
              '회원정보 수정',
              style: TextStyle(fontSize: 20, fontWeight: FontWeight.bold), // 제목 스타일
            ),
          ),
          content: Column(
            mainAxisSize: MainAxisSize.min, // 내용의 크기를 최소화
            children: [
              const Center( // 문구를 가운데 정렬
                child: Text(
                  '회원정보를 수정합니다.',
                  style: TextStyle(fontSize: 16), // 문구 스타일
                ),
              ),
              const SizedBox(height: 8), // 여백 추가
              const Center( // 문구를 가운데 정렬
                child: Text(
                  '현재 비밀번호를 입력해주세요.',
                  style: TextStyle(fontSize: 16), // 문구 스타일
                ),
              ),
              const SizedBox(height: 8), // 여백 추가
              TextField(
                obscureText: true, // 비밀번호 입력 시 텍스트 숨기기
                decoration: InputDecoration(
                  hintText: '현재 비밀번호',
                  border: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(10), // 모서리 둥글게
                    borderSide: const BorderSide(color: Colors.black), // 테두리 색상
                  ),
                  contentPadding: const EdgeInsets.all(10), // 패딩 추가
                ),
                onChanged: (value) {
                  user_pw = value; // 입력한 비밀번호를 user_pw에 저장
                },
              ),
            ],
          ),
          actions: [
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceEvenly, // 버튼을 양쪽 끝으로 배치
              children: [
                SizedBox(
                  width: 100, // 버튼의 너비를 고정
                  child: ElevatedButton(
                    onPressed: () async {
                      // 수정하기 버튼 클릭 시 서버에 요청
                      try {
                        final serverResponse = await _updateUserInfo(); // 현재 비밀번호를 전달

                        if (serverResponse['result'] == 'OK') {
                          final serverResponse1 = serverResponse['response'];
                          if (serverResponse1['result'] == 'OK') {
                            showResponseDialog(context, '수정하기 성공', '회원정보가 성공적으로 수정되었습니다.');
                            Navigator.of(context).pop(); // 모달창 닫기
                            Navigator.of(context).pop(); // 모달창 닫기
                          } else {
                            showResponseDialog(context, '${serverResponse1['response_info']['msg_title']}', '${serverResponse1['response_info']['msg_content']}');
                          }
                        } else {
                          showResponseDialog(context, '수정하기 실패', '서버에 문제가 있습니다. 관리자에게 문의해주세요.');
                        }
                      } catch (e) {
                        showResponseDialog(context, '수정하기 실패', e.toString());
                      }
                    },
                    style: ElevatedButton.styleFrom(
                      backgroundColor: Colors.white, // 버튼 배경색
                      side: const BorderSide(color: Colors.black54, width: 1), // 테두리 색상 및 두께
                      shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(40), // 모서리 둥글게 조정
                      ),
                    ),
                    child: const Text(
                      '수정하기',
                      style: TextStyle(color: Colors.black, fontSize: 14), // 텍스트 색상 및 크기
                    ),
                  ),
                ),
                SizedBox(
                  width: 100, // 버튼의 너비를 고정
                  child: ElevatedButton(
                    onPressed: () {
                      Navigator.of(context).pop(); // 모달창 닫기
                    },
                    style: ElevatedButton.styleFrom(
                      backgroundColor: Colors.white, // 버튼 배경색
                      side: const BorderSide(color: Colors.black54, width: 1), // 테두리 색상 및 두께
                      shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(40), // 모서리 둥글게 조정
                      ),
                    ),
                    child: const Text(
                      '취소',
                      style: TextStyle(color: Colors.black, fontSize: 14), // 텍스트 색상 및 크기
                    ),
                  ),
                ),
              ],
            ),
          ],
        );
      },
    );
  }

  // 사용자 정보를 업데이트하는 메서드 추가
  Future<Map<String, dynamic>> _updateUserInfo() async {
    try {
      final serverResponse = await Api.serverRequest(
        uri: '/user/update/user/info',
        body: {
          "user_pw": Utils.hashPassword(user_pw), // 서버에서 받아온 비밀번호
          "new_user_pw": Utils.hashPassword(new_user_pw), // 사용자가 입력한 새로운 비밀번호
          "user_pw_change_yn": new_user_pw != '**********' ? 'Y' : 'N', // 비밀번호 변경 여부
          "nickname": user_nickname, // 닉네임
          "user_email": user_email, // 이메일
          "department": user_department, // 소속
          "profile_img": user_profile_image, // 프로필 이미지
          "introduce_myself": user_introduce_myself, // 자기소개
        },
      );

      print('serverResponse 응답: $serverResponse');

      // 응답이 null인지 확인
      if (serverResponse == null) {
        throw Exception('서버 응답이 null입니다.');
      }

      // 응답 구조 확인
      if (serverResponse['result'] == 'OK') {
        return serverResponse; // 성공 시 응답 반환
      } else {
        return {
          'result': 'FAIL',
        };
      }
    } catch (e) {
      print('serverResponse 오류: $e');
      return {
          'result': 'FAIL',
      };
    }
  }

  // 닉네임 패턴 검증 메서드 추가
  bool _isNicknameValidPattern(String nickname) {
    // 닉네임은 3~15자 사이의 영문자와 숫자만 포함
    return RegExp(r'^[A-Za-z가-힣0-9]{2,20}$').hasMatch(nickname);
  }

  Future<void> _pickImage() async {
    final ImagePicker picker = ImagePicker();
    // 갤러리에서 이미지 선택
    final XFile? selectedImage = await picker.pickImage(source: ImageSource.gallery);
    
    if (selectedImage != null) {
      // 선택된 이미지가 있을 경우 서버에 업로드
      final serverResponse = await Api.uploadProfileImage(selectedImage, body: {
        'test': 'test', // 필요한 데이터 추가
      });

      if (serverResponse['result'] == 'OK') {
        final serverResponse1 = serverResponse['response'];
        print('응답: $serverResponse1');
        if (serverResponse1['result'] == 'OK') {
          showResponseDialog(context, '업로드 성공', '프로필 이미지가 성공적으로 업로드되었습니다.');
          
          // user_profile_image 값을 업데이트 (앞의 '/images' 제거)
          setState(() {
            user_profile_image = serverResponse1['data']['img_src'].replaceFirst('/images', ''); // 앞의 '/images' 제거
          });
        } else {
          showResponseDialog(context, '${serverResponse1['response_info']['msg_title']}', '${serverResponse1['response_info']['msg_content']}');
        }
      } else {
        showResponseDialog(context, '업로드 실패', '서버에 문제가 있습니다. 관리자에게 문의해주세요.');
      }
    }
  }
} 