import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:shared_preferences/shared_preferences.dart';
import 'dart:convert';
import '../../plugins/utils.dart';
import '../../plugins/api.dart';
import '../../dialogs/response_dialog.dart';
import '../login/login_page.dart'; // 로그인 페이지 임포트 추가

class WithdrawalPage extends StatefulWidget {
  const WithdrawalPage({Key? key}) : super(key: key);

  @override
  _WithdrawalPageState createState() => _WithdrawalPageState();
}

class _WithdrawalPageState extends State<WithdrawalPage> {
  bool _isAgreed = false; // 체크박스 상태를 관리하는 변수
  final TextEditingController _passwordController = TextEditingController(); // 비밀번호 입력 컨트롤러

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(
        title: const Text('회원탈퇴', style: TextStyle(color: Colors.black)),
        backgroundColor: Colors.transparent,
        leading: IconButton(
          icon: const Icon(Icons.arrow_back_ios, color: Colors.black),
          onPressed: () => Navigator.pop(context),
        ),
      ),
      body: Padding(
        padding: const EdgeInsets.all(16.0),
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            const Text(
              '회원탈퇴를 진행합니다.\n현재 비밀번호를 입력해주세요.',
              textAlign: TextAlign.center,
              style: TextStyle(fontSize: 18),
            ),
            const SizedBox(height: 20),
            TextField(
              controller: _passwordController,
              obscureText: true,
              decoration: InputDecoration(
                hintText: '비밀번호 입력',
                border: OutlineInputBorder(
                  borderRadius: BorderRadius.circular(10),
                  borderSide: const BorderSide(color: Colors.black),
                ),
                contentPadding: const EdgeInsets.all(10),
              ),
            ),
            const SizedBox(height: 20),
            Container(
              decoration: BoxDecoration(
                border: Border.all(color: Colors.black54, width: 1), // 테두리 설정
                borderRadius: BorderRadius.circular(10), // 모서리 둥글게
              ),
              padding: const EdgeInsets.all(16.0), // 내부 여백
              child: const Text(
                '[회원 탈퇴 안내]\n'
                '회원 탈퇴를 진행하시겠습니까?\n'
                ' - 회원 탈퇴 시 등록하신 모든 개인정보(ID, 비밀번호, 닉네임, 이메일 주소, 소속, 자기소개 등)는 즉시 삭제되며 복구가 불가능합니다.\n'
                ' - 탈퇴 후 동일한 아이디로 재가입이 불가능할 수 있습니다.\n'
                ' - 관련 법령에 따라 일정 기간 보관이 필요한 경우 해당 기간 동안 법령이 허용하는 범위 내에서만 보관됩니다.\n'
                '탈퇴를 원하시면 아래의 "동의" 버튼을 눌러주시기 바랍니다.',
                textAlign: TextAlign.left,
                style: TextStyle(fontSize: 12),
              ),
            ),
            const SizedBox(height: 20),
            Row(
              children: [
                Checkbox(
                  value: _isAgreed, // 체크박스 상태
                  activeColor: Colors.black, // 체크박스가 활성화될 때의 색상
                  checkColor: Colors.white, // 체크 표시 색상
                  onChanged: (value) {
                    setState(() {
                      _isAgreed = value ?? false; // 체크박스 상태 변경
                    });
                  },
                ),
                const Expanded(
                  child: Text(
                    '회원탈퇴에 동의합니다.',
                    style: TextStyle(fontSize: 16),
                  ),
                ),
              ],
            ),
            const SizedBox(height: 20),
            ElevatedButton(
              onPressed: () {
                // 탈퇴하기 버튼 클릭 시의 동작을 여기에 추가
                _requestWithdrawal(_passwordController.text, _isAgreed);
              },
              style: ElevatedButton.styleFrom(
                backgroundColor: Colors.black54, // 버튼 배경색
                padding: const EdgeInsets.symmetric(vertical: 12, horizontal: 60), // 버튼 패딩
              ),
              child: const Text(
                '탈퇴하기',
                style: TextStyle(color: Colors.white, fontSize: 16), // 텍스트 색상 및 크기
              ),
            ),
          ],
        ),
      ),
    );
  }

  Future<void> _requestWithdrawal(String password, bool isAgreed) async {
    if (!isAgreed) {
      // 체크박스가 체크되지 않은 경우
      showResponseDialog(context, '회원탈퇴 동의 확인', '회원탈퇴 동의 체크가 필요합니다.');
      return;
    }

    if (password.isEmpty) {
      // 비밀번호가 입력되지 않은 경우
      showResponseDialog(context, '비밀번호 확인', '비밀번호를 입력해야 합니다.');
      return;
    }

    final response = await Api.serverRequest(
      uri: '/user/withdraw/user',
      body: {
        'user_pw': Utils.hashPassword(password), // 입력한 비밀번호
      },
    );

    if (response['result'] == 'OK') {
      final serverResponse = response['response'];
      if (serverResponse['result'] == 'OK') {
        // 회원탈퇴 완료 후 로그인 페이지로 이동
        SharedPreferences prefs = await SharedPreferences.getInstance();
        await prefs.remove('auth_token'); // 토큰 초기화

        showResponseDialog(context, '회원탈퇴 완료', '회원탈퇴가 완료되었습니다.');
        Navigator.pushReplacement(
          context,
          MaterialPageRoute(builder: (context) => const LoginPage()), // 로그인 페이지로 이동
        );
      } else {
        showResponseDialog(context, serverResponse['response_info']['msg_title'], serverResponse['response_info']['msg_content']);
      }
    } else {
      showResponseDialog(context, '회원탈퇴 실패', '서버에 문제가 있습니다. 관리자에게 문의해주세요.');
    }
  }
} 